#
# spec file for package python-python-gitlab
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-python-gitlab
Version:        5.6.0
Release:        1.1
Summary:        Python module for interacting with the GitLab API
License:        LGPL-3.0-only
URL:            https://github.com/python-gitlab/python-gitlab
Source:         https://files.pythonhosted.org/packages/source/p/python_gitlab/python_gitlab-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.9}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION requirements
# https://github.com/python-gitlab/python-gitlab/blob/main/pyproject.toml#L19
BuildRequires:  %{python_module PyYAML >= 6.0.1}
# relax constraint, as Tumbleweed already has 3.x
BuildRequires:  %{python_module argcomplete >= 1.10.0 with %python-argcomplete < 4 }
BuildRequires:  %{python_module gql >= 3.5.0 with %python-gql < 4 }
BuildRequires:  %{python_module requests >= 2.32.0}
BuildRequires:  %{python_module requests-toolbelt >= 1.0.0}
# /SECTION
# SECTION test requirements
BuildRequires:  %{python_module httmock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module responses}
BuildRequires:  %{python_module respx}
BuildRequires:  %{python_module trio}
# /SECTION
# SECTION runtime requirements
Requires:       python-PyYAML >= 6.0.1
Requires:       python-requests >= 2.32.3
Requires:       python-requests-toolbelt >= 1.0.0
# relax constraint, as Tumbleweed already has 3.x
Requires:       (python-argcomplete >= 1.10.0 with python-argcomplete < 4)
Requires:       (python-gql >= 3.5.2 with python-gql < 4)
# /SECTION
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
The python-gitlab package provides access to the GitLab server API.

It supports the v4 API of GitLab, and provides a CLI tool (gitlab).

%prep
%autosetup -p1 -n python_gitlab-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/gitlab
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
touch $HOME/.python-gitlab.cfg
%pytest tests/unit

%post
%python_install_alternative gitlab

%postun
%python_uninstall_alternative gitlab

%files %{python_files}
%doc AUTHORS CHANGELOG.md README.rst
%license COPYING
%python_alternative %{_bindir}/gitlab
%{python_sitelib}/gitlab
%{python_sitelib}/python_gitlab-%{version}.dist-info

%changelog
* Fri Apr 18 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 5.6.0:
  * Features
  - group: Add support for group level MR approval rules
    (304bdd0)
- update to 5.5.0:
  * Chores Add deprecation warning for mirror_pull functions
    (7f6fd5c) Relax typing constraints for response action
    (f430078) tests: Catch deprecation warnings (0c1af08)
  * Documentation Add usage of pull mirror (9b374b2) Remove old
    pull mirror implementation (9e18672)
  * Features projects: Add pull mirror class (2411bff)
- update to 5.4.0:
  * Bug Fixes
  - api: Make type ignores more specific where possible (e3cb806)
  - api: Return the new commit when calling cherry_pick (de29503)
  - files: Add optional ref parameter for cli project-file raw
    (#3032) (22f03bd)
  * Chores
  - Fix missing space in deprecation message (ba75c31)
  - Fix pytest deprecation (95db680)
  - Fix warning being generated (0eb5eb0)
  - Resolve DeprecationWarning message in CI run (accd5aa)
  - ci: Set a 30 minute timeout for 'functional' tests (e8d6953)
  - deps: Update all non-major dependencies (939505b)
  - deps: Update all non-major dependencies (cbd4263)
  - deps: Update gitlab (#3088, 9214b83)
  - deps: Update gitlab/gitlab-ee docker tag to v17.7.1-ee.0
    (#3082, 1e95944)
  - deps: Update mypy to 1.14 and resolve issues (671e711)
  - test: Prevent 'job_with_artifact' fixture running forever
    (e4673d8)
  * Continuous Integration
  - Use gitlab-runner:v17.7.1 for the CI (2dda9dc)
  * Features
  - api: Add argument that appends extra HTTP headers to a
    request (fb07b5c)
  - api: Add support for external status check (175b355)
  - api: Narrow down return type of download methods using
    typing.overload (44fd9dc)
  - api: Narrow down return type of ProjectFileManager.raw using
    typing.overload (36d9b24)
- update to 5.3.1:
  * Bug Fixes
  - api: Allow configuration of keep_base_url from file (f4f7d7a)
  - registry-protection: Fix api url (8c1aaa3)
  * Chores
  - Bump to 5.3.1 (912e1a0)
  - deps: Update dependency jinja2 to v3.1.5 [security] (01d4194)
- update to 5.3.0:
  * Chores
  - deps: Update gitlab/gitlab-ee docker tag to v17.7.0-ee.0
    (#3070, 62b7eb7)
  - renovate: Update httpx and respx again (aa07449)
  * Features
  - api: Support the new registry protection rule endpoint
    (40af1c8)
- update to 5.2.0:
  * Chores
  - deps: Update all non-major dependencies (1e02f23)
  - deps: Update all non-major dependencies (6532e8c)
  - deps: Update all non-major dependencies (8046387)
  - deps: Update codecov/codecov-action action to v5 (735efff)
  - deps: Update dependency commitizen to v4 (9306362)
  - deps: Update gitlab/gitlab-ee docker tag to v17.6.1-ee.0
    (#3053, f2992ae)
  - deps: Update gitlab/gitlab-ee docker tag to v17.6.2-ee.0
    (#3065, db0db26)
  - deps: Update pre-commit hook commitizen-tools/commitizen to
    v4 (a8518f1)
  - docs: Fix CHANGELOG tracebacks codeblocks (9fe372a)
  - renovate: Pin httpx until respx is fixed (b70830d)
  * Documentation
  - api-usage: Fix link to Gitlab REST API Authentication Docs
    (#3059, f460d95)
  * Features
  - api: Add project templates (#3057, 0d41da3)
  - feat(api): Added project template classes to templates.py
  - feat(api): Added project template managers to Project in
    project.py
  - docs(merge_requests): Add example of creating mr with
    description template
  - test(templates): Added unit tests for templates
  - docs(templates): added section for project templates
  - graphql: Add async client (288f39c)
- update to 5.1.0:
  * Chores
  - deps: Update all non-major dependencies (9061647)
  - deps: Update gitlab/gitlab-ee docker tag to v17.6.0-ee.0
    (#3044, 79113d9)
  - deps: Update all non-major dependencies (62da12a)
  - deps: Update gitlab/gitlab-ee docker tag to v17.5.2-ee.0
    (#3041, d39129b)
  - deps: Update pre-commit hook maxbrunet/pre-commit-renovate to
    v39 (11458e0)
  - deps: Update all non-major dependencies (7e62136)
  - deps: Update dependency pytest-cov to v6 (ffa88b3)
  - deps: Update all non-major dependencies (d4b52e7)
  - deps: Update all non-major dependencies (541a7e3)
  - deps: Update gitlab/gitlab-ee docker tag to v17.5.1-ee.0
    (8111f49)
  * Features
  - api: Get single project approval rule (029695d)
  - cli: Enable token rotation via CLI (0cb8171)
  - const: Add new Planner role to access levels (bdc8852)
  - api: Support list and delete for group service accounts
    (#2963, 499243b)
  - files: Add support for more optional flags (f51cd52)
- update to 5.0.0:
  * Breaking
  - feat: remove support for Python 3.8, require 3.9 or higher
    (#3005)
  * Bug Fixes
  - fix(api): set `_repr_attr` for project approval rules to name
    attr (#3011)
  * Chores
  - chore: add testing of Python 3.14
  - chore(deps): update dependency ubuntu to v24 (6fda15d)
  - chore(deps): update all non-major dependencies (1e4326b)
  - chore(deps): update gitlab/gitlab-ee docker tag to
    v17.5.0-ee.0 (c02a392)
  - chore: add Python 3.13 as supported (#3012)
  - chore: remove "v3" question from issue template (#3017)
  - chore(deps): update all non-major dependencies (b3834dc)
  - chore(deps): update gitlab/gitlab-ee docker tag to
    v17.4.2-ee.0 (1cdfe40)
  * Documentation
  - docs(users): update Gitlab docs links (#3022) (3739b5d)
  * Testing
  - test: add test for to_json() method
* Sun Mar  9 2025 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- update to 4.13.0:
  * https://github.com/python-gitlab/python-gitlab/releases/tag/v4.13.0
- update to 4.12.2:
  * https://github.com/python-gitlab/python-gitlab/releases/tag/v4.12.2
- update to 4.12.1:
  * https://github.com/python-gitlab/python-gitlab/releases/tag/v4.12.1
- update to 4.12.0:
  * https://github.com/python-gitlab/python-gitlab/releases/tag/v4.12.0
- update to 4.11.1:
  * https://github.com/python-gitlab/python-gitlab/releases/tag/v4.11.1
- update to 4.11.0:
  * https://github.com/python-gitlab/python-gitlab/releases/tag/v4.11.0
- update to 4.10.0:
  * https://github.com/python-gitlab/python-gitlab/releases/tag/v4.10.0
- update to 4.9.0:
  * https://github.com/python-gitlab/python-gitlab/releases/tag/v4.9.0
- update to 4.8.0:
  * https://github.com/python-gitlab/python-gitlab/releases/tag/v4.8.0
- update to 4.7.0:
  * https://github.com/python-gitlab/python-gitlab/releases/tag/v4.7.0
* Mon Jun  3 2024 Srinidhi B S <srinidhi.bs@gmail.com>
- Update to 4.6.0:
  * chore(deps): update python-semantic-release/upload-to-gh-release digest to 673709c (1b550ac)
  * chore(deps): update all non-major dependencies (4c7014c)
  * chore: update commit reference in git-blame-ignore-revs (d0fd5ad)
  * chore(cli): add ability to not add _id_attr as an argument
  * chore: create a CustomAction dataclass (61d8679)
  * chore: add an initial .git-blame-ignore-revs
  * chore: require keyword arguments for register_custom_action
  * chore: remove typing-extensions from requirements.txt
  * chore(deps): update dependency requests to v2.32.0 [security] (1bc788c)
  * chore(deps): update all non-major dependencies (ba1eec4)
  * chore(deps): update gitlab/gitlab-ee docker tag to v17 (5070d07)
  * chore(cli): on the CLI help show the API endpoint of resources
  * chore(cli): add some simple help for the standard operations
  * chore: correct type-hint for job.trace()
  * chore: add type info for ProjectFile.content
  * feat(api): add additional parameter to project/group iteration search (#2796)
  * feat(api): add support for gitlab service account (#2851)
  * feat: more usernames support for MR approvals
  * fix(deps): update minimum dependency versions in pyproject.toml
  * fix(cli): don't require --id when enabling a deploy key
  * fix: don't raise RedirectError for redirected HEAD requests (8fc13b9)
  * fix: handle large number of approval rules
  * fix(projects): fix 'import_project' file argument type for typings
- Update to 4.5.0:
  * build: Add "--no-cache-dir" to pip commands in Dockerfile
  * chore(deps): update all non-major dependencies (4f338ae)
  * chore(deps): update gitlab/gitlab-ee docker tag to v16.11.2-ee.0 (9be48f0)
  * chore(deps): update dependency myst-parser to v3 (9289189)
  * chore(deps): update all non-major dependencies (65d0e65)
  * chore(deps): update dependency jinja2 to v3.1.4 [security] (8ea10c3)
  * chore(deps): update all non-major dependencies (1f0343c)
  * chore(deps): update gitlab/gitlab-ee docker tag to v16.11.1-ee.0 (1ed8d6c)
  * chore(deps): update all non-major dependencies (0e9f4da)
  * chore(deps): update gitlab/gitlab-ee docker tag to v16 (ea8c4c2)
  * chore(deps): update all non-major dependencies (d5b5fb0)
  * chore(deps): update dependency pytest-cov to v5 (db32000)
  * chore: update mypy to 1.9.0 and resolve one issue
  * chore(deps): update dependency black to v24.3.0 [security] (f6e8692)
  * chore(deps): update all non-major dependencies (14a3ffe)
  * chore(deps): update all non-major dependencies (3c4dcca)
  * chore(deps): update all non-major dependencies (04c569a)
  * chore: add tox labels to enable running groups of environments
  * chore: add py312 & py313 to tox environment list
  * chore(deps): update python-semantic-release/python-semantic-release action to v9 (e11d889)
  * chore(deps): update all non-major dependencies (3c4b27e)
  * chore(deps): update dependency furo to v2024 (f6fd02d)
  * chore(deps): update dependency pytest to v8 (253babb)
  * chore(deps): update dependency pytest-docker to v3 (35d2aec)
  * chore: update version of black for pre-commit
  * chore(deps): update all non-major dependencies (7dc2fa6)
  * chore(deps): update codecov/codecov-action action to v4 (d2be1f7)
  * chore: adapt style for black v24 (4e68d32)
  * chore(deps): update dependency black to v24 (f59aee3)
  * chore(deps): update all non-major dependencies (48726fd)
  * docs: add FAQ about conflicting parameters
  * docs(README): tweak GitLab CI usage docs (d9aaa99)
  * docs: how to run smoke tests
  * docs(objects): minor rst formatting typo
  * docs: correct rotate token example
  * docs: Note how to use the Docker image from within GitLab CI
  * docs(artifacts): Fix argument indentation (c631eeb)
  * feat(job_token_scope): support Groups in job token allowlist API (#2816)
  * feat(job_token_scope): support job token access allowlist API
  * feat(cli): allow skipping initial auth calls (001e596)
  * feat(api): allow updating protected branches (#2771)
  * feat(api): allow updating protected branches
  * fix: Consider scope an ArrayAttribute in PipelineJobManager
  * fix(test): use different ids for merge request, approval rule, project
  * fix(api): fix saving merge request approval rules
  * fix: user.warn() to show correct filename of issue
  * fix(api): update manual job status when playing it (9440a32)
  * fix(cli): allow exclusive arguments as optional (#2770)
  * fix(cli): allow exclusive arguments as optional
  * fix(cli): inform argument parser that options are mutually exclusive
  * fix(cli): use correct exclusive options, add unit test
  * test: remove approve step
  * test: tidy up functional tests
  * test: update api tests for GL 16.10
  * test(functional): enable bulk import feature flag before test (b81da2e)
  * test: don't use weak passwords
  * test: update tests for gitlab 16.8 functionality
  * test(smoke): normalize all dist titles for smoke tests (ee013fe)
* Thu Mar 14 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.4.0:
  * feat(api): add support for the Draft notes API
  * fix(client): handle empty 204 reponses in PUT requests
  * fix(cli): add ability to disable SSL verification
  * feat: add pipeline status as Enum
  * feat(api): add support for wiki attachments
  * feat: add Merge Request merge_status and detailed_merge_status values as
    constants
  * fix: remove deprecated MergeStatus
  * BREAKING CHANGE: python-gitlab now stores metadata in pyproject.toml
  * refactor(artifacts): remove deprecated `artifact()`in favor of
    `artifacts.raw()`
  * refactor(artifacts): remove deprecated `artifacts()`in favor of
    `artifacts.download()`
  * refactor(groups): remove deprecated LDAP group link add/delete methods
  * refactor(projects): remove deprecated `project.transfer_project()` in
    favor of `project.transfer()`
  * fix(cli): remove deprecated `--all` option in favor of `--get-all`
  * feat: remove support for Python 3.7, require 3.8 or higher
  * chore: update PyYAML to 6.0.1
  * feat(client): mask tokens by default when logging
  * feat(api): add ProjectPackagePipeline
  * feat: officially support Python 3.12
  * feat(packages): Allow uploading bytes and files
  * feat: Use requests AuthBase classes
  * feat(api): add support for job token scope settings
  * feat(api): support project remote mirror deletion
  * feat(api): add optional GET attrs for /projects/:id/ci/lint
  * feat(api): add support for new runner creation API
  * feat(releases): Add support for direct_asset_path
  * feat: Added iteration to issue and group filters
  * test: fix failing tests that use 204 (No Content) plus content
  * update dependency `responses==0.23.3` as it provides support for
    `urllib3>=2`
- Switch to pyproject macros.
* Thu Oct 12 2023 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file
* Thu Oct 12 2023 Ondřej Súkup <mimi.vx@gmail.com>
- Update to 3.15.0
- force urllib3 < 2 for testsuite
  * Add support for select="package_file" in package upload (3a49f09)
  * api: Add support for events scope parameter (348f56e
  * Usernames support for MR approvals ()a2b8c8c)
  * Remove exclusive EE about issue links (e0f6f18)
  * projects: Allow importing additional items from GitHub (ce84f2e)
  * objects: Support fetching PATs via id or self endpoint (19b38bd)
  * Add resource_weight_event for ProjectIssue (6e5ef55)
  * backends: Use PEP544 protocols for structural subtyping (#2442) (4afeaff)
  * client: Add http_patch method (#2471) (f711d9e)
  * cli: Add setting of allow_force_push for protected branch (929e07d)
  * cli: Warn user when no fields are displayed (8bf53c8)
  * client: Properly parse content-type when charset is present (76063c3)
  * Support int for parent_id in import_group (90f96ac)
  * cli: Add ability to escape at-prefixed parameter (#2513) (4f7c784)
  * cli: Display items when iterator is returned (33a04e7)
  * objects: Fix typo in pipeline schedules (3057f45)
  * advanced: Clarify netrc, proxy behavior with requests (1da7c53)
  * Fix update badge behaviour (3d7ca1c)
  * advanced: Fix typo in Gitlab examples (1992790)
  * group: Add support for group restore API (9322db6)
  * client: Automatically retry on HTTP 409 Resource lock (dced76a)
  * api: Add support for bulk imports API (043de2d)
  * api: Add support for resource groups (5f8b8f5)
  * api: Support listing pipelines triggered by pipeline schedules (865fa41)
  * Allow filtering pipelines by source (b6c0872)
  * client: Bootstrap the http backends concept (#2391) (91a665f)
  * Add resource iteration events (see https://docs.gitlab.com/ee/api/resource_iteration_events.html)
  * Allow passing kwargs to Gitlab class when instantiating with from_config (#2392) (e88d34e)
  * Add keep_base_url when getting configuration from file (50a0301)
  * client: Regression - do not automatically get_next if page=# and (585e3a8)
  * Change return value to "None" in case getattr returns None to prevent error (3f86d36)
  * deps: Bump requests-toolbelt to fix deprecation warning (faf842e)
  * Use the ProjectIterationManager within the Project object (44f05dc)
  * api: Make description optional for releases (5579750)
  * faq: Describe and group common errors (4c9a072)
* Mon Dec 12 2022 pgajdos@suse.com
- six is not required
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v3.12.0
  * Feature
  Add support for SAML group links (#2367) (1020ce9)
  groups: Add LDAP link manager and deprecate old API endpoints (3a61f60)
  groups: Add support for listing ldap_group_links (#2371) (ad7c8fa)
  Implement secure files API (d0a0348)
  ci: Re-Run Tests on PR Comment workflow (034cde3)
  api: Add support for getting a project's pull mirror details (060cfe1)
  api: Add support for remote project import from AWS S3 (#2357) (892281e)
  api: Add support for remote project import (#2348) (e5dc72d)
  api: Add application statistics (6fcf3b6)
  * Fix
  cli: Enable debug before doing auth (65abb85)
  cli: Expose missing mr_default_target_self project attribute (12aea32)
  Use POST method and return dict in cancel_merge_when_pipeline_succeeds() (#2350) (bd82d74)
  * Documentation
  Use the term "log file" for getting a job log file (9d2b1ad)
  groups: Describe GitLab.com group creation limitation (9bd433a)
  api: Pushrules remove saying None is returned when not found (c3600b4)
* Wed Nov  9 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v3.11.0
  Feature
  * build: Officially support Python 3.11 (74f66c7)
  * api: Add support for topics merge API (9a6d197)
  Fix
  * Remove project.approvals.set_approvals() method (91f08f0)
  * Use epic id instead of iid for epic notes (97cae38)
  * cli: Handle list response for json/yaml output (9b88132)
  * Intermittent failure in test_merge_request_reset_approvals (3dde36e)
  Documentation
  * advanced: Add hint on type narrowing (a404152)
  * Add minimal docs about the enable_debug() method (b4e9ab7)
  commits: Fix commit create example for binary content (bcc1eb4)
  * readme: Add a basic feature list (b4d53f1)
  * api: Describe use of lower-level methods (b7a6874)
  * api: Describe the list() and all() runners' functions (b6cc3f2)
  * api: Update merge_requests.rst: mr_id to mr_iid (b32234d)
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v3.10.0 (2022-09-28)
  Feature
  Add reset_approvals api (88693ff)
  Add support for deployment approval endpoint (9c9eeb9)
  Fix
  cli: Add missing attributes for creating MRs (1714d0a)
  cli: Add missing attribute for MR changes (20c46a0)
* Thu Oct  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v3.9.0 (2022-08-28)
  Feature
  Add support for merge_base API (dd4fbd5)
- Update to v3.8.1 (2022-08-10)
  Fix
  client: Do not assume user attrs returned for auth() (a07547c)
- Update to v3.8.0 (2022-08-04)
  Feature
  client: Warn user on misconfigured URL in auth() (0040b43)
  Support downloading archive subpaths (cadb0e5)
  Fix
  client: Ensure encoded query params are never duplicated (1398426)
  Optionally keep user-provided base URL for pagination (#2149) (e2ea8b8)
  Documentation
  Describe self-revoking personal access tokens (5ea48fc)
- v3.7.0 (2022-07-28)
  Feature
  Allow sort/ordering for project releases (b1dd284)
  cli: Add a custom help formatter (005ba93)
  Add support for iterations API (194ee01)
  groups: Add support for shared projects API (66461ba)
  issues: Add support for issue reorder API (8703324)
  namespaces: Add support for namespace existence API (4882cb2)
  Add support for group and project invitations API (7afd340)
  projects: Add support for project restore API (4794ecc)
  Add support for filtering jobs by scope (0e1c0dd)
  Add asdict() and to_json() methods to Gitlab Objects (08ac071)
  api: Add support for instance-level registry repositories (284d739)
  groups: Add support for group-level registry repositories (70148c6)
  Add 'merge_pipelines_enabled' project attribute (fc33c93)
  Support validating CI lint results (3b1ede4)
  cli: Add support for global CI lint (3f67c4b)
  objects: Add Project CI Lint support (b213dd3)
  Add support for group push rules (b5cdc09)
  api: Add support for get for a MR approval rule (89c18c6)
  Fix
  Support array types for most resources (d9126cd)
  Use the [] after key names for array variables in params (1af44ce)
  runners: Fix listing for /runners/all (c6dd57c)
  config: Raise error when gitlab id provided but no config section found (1ef7018)
  config: Raise error when gitlab id provided but no config file found (ac46c1c)
  Add get_all param (and --get-all) to allow passing all to API (7c71d5d)
  Results returned by attributes property to show updates (e5affc8)
  Enable epic notes (5fc3216)
  cli: Remove irrelevant MR approval rule list filters (0daec5f)
  Ensure path elements are escaped (5d9c198)
  Documentation
  cli: Showcase use of token scopes (4a6f8d6)
  projects: Document export with upload to URL (03f5484)
  Describe fetching existing export status (9c5b8d5)
  authors: Add John (e2afb84)
  Document CI Lint usage (d5de4b1)
  users: Add docs about listing a user's projects (065a1a5)
  Update return type of pushrules (53cbecc)
  Describe ROPC flow in place of password authentication (91c17b7)
  readme: Remove redundant -v that breaks the command (c523e18)
- v3.6.0 (2022-06-28)
  Feature
  downloads: Allow streaming downloads access to response iterator (#1956) (b644721)
  api: Support head() method for get and list endpoints (ce9216c)
  api: Implement HEAD method (90635a7)
  users: Add approve and reject methods to User (f57139d)
  api: Convert gitlab.const to Enums (c3c6086)
  Add support for Protected Environments (1dc9d0f)
  users: Add ban and unban methods (0d44b11)
  docker: Provide a Debian-based slim image (384031c)
  Support mutually exclusive attributes and consolidate validation to fix board lists (#2037) (3fa330c)
  client: Introduce iterator=True and deprecate as_list=False in list() (cdc6605)
  Fix
  base: Do not fail repr() on lazy objects (1efb123)
  cli: Project-merge-request-approval-rule (15a242c)
  cli: Fix project export download for CLI (5d14867)
  Documentation
  api: Add separate section for advanced usage (22ae101)
  api: Document usage of head() methods (f555bfb)
  projects: Provide more detailed import examples (8f8611a)
  projects: Document 404 gotcha with unactivated integrations (522ecff)
  variables: Instruct users to follow GitLab rules for values (194b6be)
  api: Stop linking to python-requests.org (49c7e83)
  api: Fix incorrect docs for merge_request_approvals (#2094) (5583eaa)
  api-usage: Add import os in example (2194a44)
  Drop deprecated setuptools build_sphinx (048d66a)
  usage: Refer to upsteam docs instead of custom attributes (ae7d3b0)
  ext: Fix rendering for RequiredOptional dataclass (4d431e5)
  Documentation updates to reflect addition of mutually exclusive attributes (24b720e)
  Use as_list=False or all=True in Getting started (de8c6e8)
* Wed May  4 2022 pgajdos@suse.com
- version update to 3.4.0
  too many changes, see CHANGELOG.md in documantation or at
  https://github.com/python-gitlab/python-gitlab/blob/main/CHANGELOG.md
- python-mock is not required for build
* Thu Jan 14 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v2.5.0
  * add support to resource milestone events
  * add share/unshare group with group
  * add support for instance variables
  * add support for Packages API
  * add endpoint for latest ref artifacts
  * wrong reconfirmation parameter when updating user's email
  * tests fail when using REUSE_CONTAINER option
  * implement Gitlab's behavior change for owned=True
- from v2.4.0
  * do not check if kwargs is none
  * make query kwargs consistent between call in init and next
  * pass kwargs to subsequent queries in gitlab list
  * merge: parse arguments as query_data
  * add NO_ACCESS const
  * add masked parameter for variables command
- from v2.3.1
  * revert keyset pagination by default
- from v2.3.0
  * add group runners api
  * add play command to project pipeline schedules
  * allow an environment variable to specify config location
  * api: added support in the GroupManager to upload Group avatars
  * services: add project service list API
  * types: add dir to RESTObject to expose attributes
  * use keyset pagination by default for /projects > 50000
  * config: fix duplicate code
  * project: add missing project parameters
* Mon May  4 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
- Update to 2.2.0:
  - add missing import_project param
  - types: do not split single value string in ListAttribute
  - add commit GPG signature API
  - add create from template args to ProjectManager
  - add remote mirrors API (#1056)
  - add Gitlab Deploy Token API
  - add Group Import/Export API (#1037)
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix dependencies for testing
* Fri Mar 20 2020 pgajdos@suse.com
- version update to 2.1.2
  * This releases drops support for python < 3.6
  * lot of other changes, see
    https://github.com/python-gitlab/python-gitlab/releases
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.11.0:
  * add methods to retrieve an individual project environment
  * group labels with subscriptable mixin
  * add mr rebase method bc4280c
  * get artifact by ref and job cda1174
  * add support for board update 908d79f, closes #801
  * add support for issue.related_merge_requests 90a3631, closes #794
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.9.0:
  * implement artifacts deletion
  * add endpoint to get the variables of a pipeline
  * delete ProjectPipeline
  * implement __eq__ and __hash__ methods
  * Allow runpy invocation of CLI tool (python -m gitlab)
  * add project releases api
  * merged new release & registry apis
* Thu May  9 2019 pgajdos@suse.com
- version update to 1.8.0
  * fix(api): make reset_time_estimate() work again
  * fix: handle empty 'Retry-After' header from GitLab
  * fix: remove decode() on error_message string
  * fix(api): avoid parameter conflicts with python and gitlab
  * fix(api): Don't try to parse raw downloads
  * feat: Added approve & unapprove method for Mergerequests
  * fix all kwarg behaviour
* Mon Dec 31 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 1.7.0:
  * [docs] Fix the owned/starred usage documentation
  * [docs] Add a warning about http to https redirects
  * Fix the https redirection test
  * [docs] Add a note about GroupProject limited API
  * Add missing comma in ProjectIssueManager _create_attrs
  * More flexible docker image
  * Add project protected tags management
  * [cli] Print help and usage without config file
  * Rename MASTER_ACCESS to MAINTAINER_ACCESS
  * [docs] Add docs build information
  * Use docker image with current sources
  * [docs] Add PyYAML requirement notice
  * Add Gitter badge to README
  * [docs] Add an example of pipeline schedule vars listing
  * [cli] Exit on config parse error, instead of crashing
  * Add support for resource label events
  * [docs] Fix the milestone filetring doc (iid -> iids)
  * [docs] Fix typo in custom attributes example
  * Improve error message handling in exceptions
  * Add support for members all() method
  * Add access control options to protected branch creation
  * [docs] Don't use hardcoded values for ids
  * [docs] Improve the snippets examples
  * [cli] Output: handle bytes in API responses
  * [cli] Fix the case where we have nothing to print
  * Project import: fix the override_params parameter
  * Support group and global MR listing
  * Implement MR.pipelines()
  * MR: add the squash attribute for create/update
  * Added support for listing forks of a project
  * [docs] Add/update notes about read-only objects
  * Raise an exception on https redirects for PUT/POST
  * [docs] Add a FAQ
  * [cli] Fix the project-export download
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed Aug  8 2018 jengelh@inai.de
- Use noun phrase in summary.
* Fri Aug  3 2018 toddrme2178@gmail.com
- Initial version
